@@ -23,6 +23,8 @@
  * Author: Carl D. Worth <cworth@cworth.org>
  */
 
+#include "cairo-test.h"
+
 #include <stdio.h>
 
 #include <cairo.h>
@@ -35,8 +37,6 @@
 #include <cairo-pdf.h>
 #endif
 
-#include "cairo-test.h"
-
 /* The PostScript and PDF backends are now integrated into the main
  * test suite, so we are getting good verification of most things
  * there.
@@ -51,6 +51,7 @@
 #define HEIGHT_IN_INCHES 3
 #define WIDTH_IN_POINTS  (WIDTH_IN_INCHES  * 72.0)
 #define HEIGHT_IN_POINTS (HEIGHT_IN_INCHES * 72.0)
+#define BASENAME         "multi-page.out"
 
 static void
 draw_smiley (cairo_t *cr, double width, double height, double smile_ratio)
@@ -127,30 +128,28 @@ draw_some_pages (cairo_surface_t *surface)
     cairo_destroy (cr);
 }
 
-int
-main (void)
+static cairo_test_status_t
+preamble (cairo_test_context_t *ctx)
 {
-    cairo_test_context_t ctx;
     cairo_surface_t *surface;
     cairo_status_t status;
-    const char *filename;
+    char *filename;
     cairo_test_status_t result = CAIRO_TEST_UNTESTED;
-
-    cairo_test_init (&ctx, "multi-page");
+    const char *path = cairo_test_mkdir (CAIRO_TEST_OUTPUT_DIR) ? CAIRO_TEST_OUTPUT_DIR : ".";
 
 #if CAIRO_HAS_PS_SURFACE
-    if (cairo_test_is_target_enabled (&ctx, "ps2") ||
-        cairo_test_is_target_enabled (&ctx, "ps3"))
+    if (cairo_test_is_target_enabled (ctx, "ps2") ||
+        cairo_test_is_target_enabled (ctx, "ps3"))
     {
 	if (result == CAIRO_TEST_UNTESTED)
 	    result = CAIRO_TEST_SUCCESS;
 
-	filename = "multi-page.ps";
+	xasprintf (&filename, "%s/%s", path, BASENAME ".ps");
 	surface = cairo_ps_surface_create (filename,
 					   WIDTH_IN_POINTS, HEIGHT_IN_POINTS);
 	status = cairo_surface_status (surface);
 	if (status) {
-	    cairo_test_log (&ctx, "Failed to create ps surface for file %s: %s\n",
+	    cairo_test_log (ctx, "Failed to create ps surface for file %s: %s\n",
 			    filename, cairo_status_to_string (status));
 	    result = CAIRO_TEST_FAILURE;
 	}
@@ -160,20 +159,21 @@ main (void)
 	cairo_surface_destroy (surface);
 
 	printf ("multi-page: Please check %s to ensure it looks happy.\n", filename);
+	free (filename);
     }
 #endif
 
 #if CAIRO_HAS_PDF_SURFACE
-    if (cairo_test_is_target_enabled (&ctx, "pdf")) {
+    if (cairo_test_is_target_enabled (ctx, "pdf")) {
 	if (result == CAIRO_TEST_UNTESTED)
 	    result = CAIRO_TEST_SUCCESS;
 
-	filename = "multi-page.pdf";
+	xasprintf (&filename, "%s/%s", path, BASENAME ".pdf");
 	surface = cairo_pdf_surface_create (filename,
 					    WIDTH_IN_POINTS, HEIGHT_IN_POINTS);
 	status = cairo_surface_status (surface);
 	if (status) {
-	    cairo_test_log (&ctx, "Failed to create pdf surface for file %s: %s\n",
+	    cairo_test_log (ctx, "Failed to create pdf surface for file %s: %s\n",
 			    filename, cairo_status_to_string (status));
 	    result = CAIRO_TEST_FAILURE;
 	}
@@ -183,10 +183,16 @@ main (void)
 	cairo_surface_destroy (surface);
 
 	printf ("multi-page: Please check %s to ensure it looks happy.\n", filename);
+	free (filename);
     }
 #endif
 
-    cairo_test_fini (&ctx);
-
     return result;
 }
+
+CAIRO_TEST (multi_page,
+	    "Check the paginated surfaces handle multiple pages.",
+	    "paginated", /* keywords */
+	    "target=vector", /* requirements */
+	    0, 0,
+	    preamble, NULL)
